==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource__24TitledBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$TitledBorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class c5834f4eebfdaf66 javax_swing_border_TitledBorder
// @dep_class 97128bfcd8ed9b40 javax_swing_plaf_BorderUIResource__24TitledBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_TitledBorder

#include "javax/swing/border/TitledBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$ea8eb7f460af3899(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$77080fe9e5328872(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$2c6351d5b8c291f1(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$ad8d6c2b5245c9a7(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_awt_Font$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$8a673ef422907f41(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_awt_Font$object *, struct _jc_java_awt_Color$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_TitledBorder$vmethods	javax_swing_border_TitledBorder;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24TitledBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24TitledBorderUIResource;
    _jc_javax_swing_border_TitledBorder$sub_refs	javax_swing_border_TitledBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_TitledBorder$sub_nonrefs	javax_swing_border_TitledBorder;
    _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24TitledBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24TitledBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource__24TitledBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$TitledBorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class c5834f4eebfdaf66 javax_swing_border_TitledBorder
// @dep_class 97128bfcd8ed9b40 javax_swing_plaf_BorderUIResource__24TitledBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_TitledBorder

#include "javax/swing/border/TitledBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Font$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$ea8eb7f460af3899(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$77080fe9e5328872(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$2c6351d5b8c291f1(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$ad8d6c2b5245c9a7(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_awt_Font$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$method$_init$8a673ef422907f41(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object *, struct _jc_object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_awt_Font$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_TitledBorder$vmethods	javax_swing_border_TitledBorder;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24TitledBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24TitledBorderUIResource;
    _jc_javax_swing_border_TitledBorder$sub_refs	javax_swing_border_TitledBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_TitledBorder$sub_nonrefs	javax_swing_border_TitledBorder;
    _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24TitledBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24TitledBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24TitledBorderUIResource_H_ */
